<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Ninguno',
    'Edit' => 'Modificar',
    'Remove' => 'Eliminar',
    'Yes' => 'Sí',
    'No' => 'No',
    'cancel' => 'cancelar',
    'or' => 'o',
    'Yellow' => 'amarillo',
    'Blue' => 'azul',
    'Green' => 'verde',
    'Purple' => 'púrpura',
    'Red' => 'rojo',
    'Orange' => 'anaranjado',
    'Grey' => 'gris',
    'Brown' => 'marrón',
    'Deep Orange' => 'anaranjado oscuro',
    'Dark Grey' => 'gris oscuro',
    'Pink' => 'rosado',
    'Teal' => 'verde azulado',
    'Cyan' => 'azul claro',
    'Lime' => 'verde limón',
    'Light Green' => 'verde claro',
    'Amber' => 'ámbar',
    'Save' => 'Guardar',
    'Login' => 'Iniciar sesión',
    'Official website:' => 'Página web oficial :',
    'Unassigned' => 'Sin asignar',
    'View this task' => 'Ver esta tarea',
    'Remove user' => 'Eliminar un usuario(a)',
    'Do you really want to remove this user: "%s"?' => '¿Realmente quiere eliminar este usuario(a): « %s » ?',
    'All users' => 'Todos los usuario(a)s',
    'Username' => 'Nombre de usuario(a)',
    'Password' => 'Contraseña',
    'Administrator' => 'Administrador(a)',
    'Sign in' => 'Iniciar sesión',
    'Users' => 'Usuario(a)s',
    'Forbidden' => 'Proibido',
    'Access Forbidden' => 'Acceso prohibido',
    'Edit user' => 'Editar usuario(a)',
    'Logout' => 'Cerrar sesión',
    'Bad username or password' => 'Usuario(a) incorrecto(a) y/o contraseña incorrecta',
    'Edit project' => 'Editar proyecto',
    'Name' => 'Nombre',
    'Projects' => 'Proyectos',
    'No project' => 'Sin proyecto alguno',
    'Project' => 'Proyecto',
    'Status' => 'Estado',
    'Tasks' => 'Tareas',
    'Board' => 'Tablero',
    'Actions' => 'Acciones',
    'Inactive' => 'Inactivo',
    'Active' => 'Activo',
    'Unable to update this board.' => 'No se puede actualizar este tablero.',
    'Disable' => 'Desactivar',
    'Enable' => 'Activar',
    'New project' => 'Proyecto nuevo',
    'Do you really want to remove this project: "%s"?' => '¿Realmente quiere eliminar este proyecto: « %s » ?',
    'Remove project' => 'Eliminar proyecto',
    'Edit the board for "%s"' => 'Modificar tablero para « %s »',
    'Add a new column' => 'Añadir una nueva columna',
    'Title' => 'Título',
    'Assigned to %s' => 'Asignado(a) a %s',
    'Remove a column' => 'Eliminar esta columna',
    'Unable to remove this column.' => 'No se puede eliminar esta columna.',
    'Do you really want to remove this column: "%s"?' => '¿Realmente quiere eliminar esta columna : « %s » ?',
    'Settings' => 'Configuración de preferencias',
    'Application settings' => 'Parámetros de aplicación',
    'Language' => 'Idioma',
    'Webhook token:' => 'Token para los webhooks :',
    'API token:' => 'Token de la API:',
    'Database size:' => 'Tamaño de la base de datos:',
    'Download the database' => 'Descargar base de datos',
    'Optimize the database' => 'Optimizar base de datos',
    '(VACUUM command)' => '(Comando VACUUM)',
    '(Gzip compressed Sqlite file)' => '(Archivo Sqlite comprimido en Gzip)',
    'Close a task' => 'Cerrar una tarea',
    'Column' => 'Columna',
    'Color' => 'Color',
    'Assignee' => 'Persona asignada',
    'Create another task' => 'Crear otra tarea',
    'New task' => 'Tarea nueva',
    'Open a task' => 'Abrir una tarea',
    'Do you really want to open this task: "%s"?' => '¿Realmente quiere abrir esta tarea: « %s » ?',
    'Back to the board' => 'Regresar al tablero',
    'There is nobody assigned' => 'Nadie asignado a esta tarea',
    'Column on the board:' => 'Columna en el tablero: ',
    'Close this task' => 'Cerrar esta tarea',
    'Open this task' => 'Abrir esta tarea',
    'There is no description.' => 'No hay descripción.',
    'Add a new task' => 'Añadir una tarea nueva',
    'The username is required' => 'El nombre de usuario(a) es obligatorio',
    'The maximum length is %d characters' => 'La longitud máxima es de %d caracteres',
    'The minimum length is %d characters' => 'La longitud mínima es de %d caracteres',
    'The password is required' => 'La contraseña es obligatoria',
    'This value must be an integer' => 'Este valor debe ser un número entero',
    'The username must be unique' => 'El nombre de usuario(a) debe ser único',
    'The user id is required' => 'El identificador del usuario(a) es obligatorio',
    'Passwords don\'t match' => 'Las contraseñas no coinciden',
    'The confirmation is required' => 'La confirmación es obligatoria',
    'The project is required' => 'El proyecto es obligatorio',
    'The id is required' => 'El identificador es obligatorio',
    'The project id is required' => 'El identificador del proyecto es obligatorio',
    'The project name is required' => 'El nombre del proyecto es obligatorio',
    'The title is required' => 'El título es obligatorio',
    'Settings saved successfully.' => 'Parámetros guardados correctamente.',
    'Unable to save your settings.' => 'No se pueden guardar sus parámetros.',
    'Database optimization done.' => 'Optimización de la base de datos finalizada.',
    'Your project has been created successfully.' => 'El proyecto ha sido creado correctamente.',
    'Unable to create your project.' => 'No se puede crear el proyecto.',
    'Project updated successfully.' => 'El proyecto ha sido actualizado correctamente.',
    'Unable to update this project.' => 'No se puede actualizar el proyecto.',
    'Unable to remove this project.' => 'No se puede eliminar este proyecto.',
    'Project removed successfully.' => 'El proyecto ha sido eliminado correctamente.',
    'Project activated successfully.' => 'El proyecto ha sido activado correctamente.',
    'Unable to activate this project.' => 'No se puede activar el proyecto.',
    'Project disabled successfully.' => 'El proyecto ha sido desactivado correctamente.',
    'Unable to disable this project.' => 'No se puede desactivar el proyecto.',
    'Unable to open this task.' => 'No se puede abrir esta tarea.',
    'Task opened successfully.' => 'La tarea ha sido abierta correctamente.',
    'Unable to close this task.' => 'No se puede cerrar esta tarea.',
    'Task closed successfully.' => 'La tarea ha sido cerrada correctamente.',
    'Unable to update your task.' => 'No se puede modificar esta tarea.',
    'Task updated successfully.' => 'La tarea ha sido actualizada correctamente.',
    'Unable to create your task.' => 'No se puede crear esta tarea.',
    'Task created successfully.' => 'La tarea ha sido creada correctamente.',
    'User created successfully.' => 'El usuario(a) ha sido creado correctamente.',
    'Unable to create your user.' => 'No se puede crear este usuario(a).',
    'User updated successfully.' => 'El usuario(a) ha sido actualizado correctamente.',
    'User removed successfully.' => 'El usuario(a) ha sido creado correctamente.',
    'Unable to remove this user.' => 'No se puede crear este usuario(a).',
    'Board updated successfully.' => 'El tablero ha sido actualizado correctamente.',
    'Ready' => 'Listo',
    'Backlog' => 'En espera',
    'Work in progress' => 'En curso',
    'Done' => 'Hecho',
    'Application version:' => 'Versión de la aplicación:',
    'Id' => 'Identificador',
    'Public link' => 'Vinculación pública',
    'Timezone' => 'Zona horaria',
    'Sorry, I didn\'t find this information in my database!' => 'Lo siento no he encontrado información en la base de datos!',
    'Page not found' => 'Página no encontrada',
    'Complexity' => 'Complejidad',
    'Task limit' => 'Número máximo de tareas',
    'Task count' => 'Conteo de tareas',
    'User' => 'Usuario(a)',
    'Comments' => 'Comentarios',
    'Comment is required' => 'El comentario es obligatorio',
    'Comment added successfully.' => 'El comentario ha sido añadido correctamente.',
    'Unable to create your comment.' => 'No se puede crear este comentario.',
    'Due Date' => 'Fecha límite',
    'Invalid date' => 'Fecha no válida',
    'Automatic actions' => 'Acciones automatizadas',
    'Your automatic action has been created successfully.' => 'La acción automatizada ha sido creada correctamente.',
    'Unable to create your automatic action.' => 'No se puede crear esta acción automatizada.',
    'Remove an action' => 'Eliminar una acción',
    'Unable to remove this action.' => 'No se puede eliminar esta accción.',
    'Action removed successfully.' => 'La acción ha sido eliminada correctamente.',
    'Automatic actions for the project "%s"' => 'Acciones automatizadas para este proyecto « %s »',
    'Add an action' => 'Agregar una acción',
    'Event name' => 'Nombre del evento',
    'Action' => 'Acción',
    'Event' => 'Evento',
    'When the selected event occurs execute the corresponding action.' => 'Cuando tiene lugar el evento seleccionado, ejecutar la acción correspondiente.',
    'Next step' => 'Siguiente etapa',
    'Define action parameters' => 'Definición de los parametros de la acción',
    'Do you really want to remove this action: "%s"?' => '¿Realmente quiere eliminar esta acción « %s » ?',
    'Remove an automatic action' => 'Eliminar una acción automatizada',
    'Assign the task to a specific user' => 'Asignar una tarea a un usuario(a) específico(a)',
    'Assign the task to the person who does the action' => 'Asignar la tarea al usuario quien realiza la acción',
    'Duplicate the task to another project' => 'Duplicar la tarea a otro proyecto',
    'Move a task to another column' => 'Mover una tarea a otra columna',
    'Task modification' => 'Modificación de una tarea',
    'Task creation' => 'Creación de una tarea',
    'Closing a task' => 'Cerrar una tarea',
    'Assign a color to a specific user' => 'Asignar un color a un(a) usuario(a) específico(a)',
    'Position' => 'Posición',
    'Duplicate to project' => 'Duplicar a otro proyecto',
    'Duplicate' => 'Duplicar',
    'Link' => 'Enlace',
    'Comment updated successfully.' => 'El comentario ha sido actualizado correctamente.',
    'Unable to update your comment.' => 'No se puede actualizar este comentario.',
    'Remove a comment' => 'Eliminar un comentario',
    'Comment removed successfully.' => 'El comentario ha sido eliminado correctamente.',
    'Unable to remove this comment.' => 'No se puede eliminar este comentario.',
    'Do you really want to remove this comment?' => '¿Realmente quiere eliminar este comentario?',
    'Current password for the user "%s"' => 'Contraseña actual para el(la) usuario(a): « %s »',
    'The current password is required' => 'La contraseña es obligatoria',
    'Wrong password' => 'contraseña incorrecta',
    'Unknown' => 'Desconocido',
    'Last logins' => 'Últimos ingresos',
    'Login date' => 'Fecha de ingreso',
    'Authentication method' => 'Método de autenticación',
    'IP address' => 'Dirección IP',
    'User agent' => 'Agente de usuario',
    'Persistent connections' => 'Conexión persistente',
    'No session.' => 'No existe sesión.',
    'Expiration date' => 'Fecha de expiración',
    'Remember Me' => 'Recuérdame',
    'Creation date' => 'Fecha de creación',
    'Everybody' => 'Todo el mundo',
    'Open' => 'Abierto',
    'Closed' => 'Cerrado',
    'Search' => 'Buscar',
    'Nothing found.' => 'Nada hallado.',
    'Due date' => 'Fecha Límite',
    'Description' => 'Descripción',
    '%d comments' => '%d comentarios',
    '%d comment' => '%d comentario',
    'Email address invalid' => 'Dirección de correo inválida',
    'Your external account is not linked anymore to your profile.' => 'Su cuenta externa no está vinculada a tu perfil.',
    'Unable to unlink your external account.' => 'No se puede desvincular su cuenta externa.',
    'External authentication failed' => 'Error de autenticación externa',
    'Your external account is linked to your profile successfully.' => 'Su cuenta externa está vinculada a su perfil correctamente.',
    'Email' => 'Correo electrónico',
    'Task removed successfully.' => 'Tarea eliminada correctamente.',
    'Unable to remove this task.' => 'No pude eliminar esta tarea.',
    'Remove a task' => 'Eliminar una tarea',
    'Do you really want to remove this task: "%s"?' => '¿Realmente quiere eliminar esta tarea: "%s"?',
    'Assign automatically a color based on a category' => 'Asignar un color de forma automática basándose en la categoría',
    'Assign automatically a category based on a color' => 'Asignar una categoría de forma automática basándose en el color',
    'Task creation or modification' => 'Creación o Edición de Tarea',
    'Category' => 'Categoría',
    'Category:' => 'Categoría:',
    'Categories' => 'Categorías',
    'Your category has been created successfully.' => 'Se ha creado su categoría correctamente.',
    'This category has been updated successfully.' => 'Esta categoría se ha actualizado correctamente.',
    'Unable to update this category.' => 'No se puede actualizar esta categoría.',
    'Remove a category' => 'Eliminar una categoría',
    'Category removed successfully.' => 'Categoría eliminidad correctamente.',
    'Unable to remove this category.' => 'No se pudo eliminar esta categoría.',
    'Category modification for the project "%s"' => 'Modificación de categoría para el proyecto "%s"',
    'Category Name' => 'Nombre de categoría',
    'Add a new category' => 'Añadir una categoría nueva',
    'Do you really want to remove this category: "%s"?' => '¿Realmente quiere eliminar esta categoría: "%s"?',
    'All categories' => 'Todas las categorías',
    'No category' => 'Sin categoría',
    'The name is required' => 'El nombre es obligatorio',
    'Remove a file' => 'Borrar un archivo',
    'Unable to remove this file.' => 'No pude borrar este archivo.',
    'File removed successfully.' => 'Archivo eliminado correctamente.',
    'Attach a document' => 'Adjuntar un documento',
    'Do you really want to remove this file: "%s"?' => '¿Realmente quiere eliminar este archivo: "%s"?',
    'Attachments' => 'Archivos adjuntos',
    'Edit the task' => 'Editar la tarea',
    'Add a comment' => 'Añadir un comentario',
    'Edit a comment' => 'Editar un comentario',
    'Summary' => 'Resumen',
    'Time tracking' => 'Control de tiempo',
    'Estimate:' => 'Estimado:',
    'Spent:' => 'Transcurrido:',
    'Do you really want to remove this sub-task?' => '¿Realmente quiere eliminar esta subtarea?',
    'Remaining:' => 'Restante',
    'hours' => 'horas',
    'estimated' => 'estimado',
    'Sub-Tasks' => 'Subtareas',
    'Add a sub-task' => 'Añadir una subtarea',
    'Original estimate' => 'Horas presupuestadas',
    'Create another sub-task' => 'Crear otra subtarea',
    'Time spent' => 'Horas ejecutadas',
    'Edit a sub-task' => 'Editar una subtarea',
    'Remove a sub-task' => 'Suprimir una subtarea',
    'The time must be a numeric value' => 'El tiempo debe de ser un valor numérico',
    'Todo' => 'Por hacer',
    'In progress' => 'En progreso',
    'Sub-task removed successfully.' => 'Subtarea eliminada correctamente.',
    'Unable to remove this sub-task.' => 'No pude eliminar esta subtarea.',
    'Sub-task updated successfully.' => 'Subtarea actualizada correctamente.',
    'Unable to update your sub-task.' => 'No pude actualizar tu subtarea.',
    'Unable to create your sub-task.' => 'No pude crear tu subtarea.',
    'Maximum size: ' => 'Tamaño máximo',
    'Display another project' => 'Mostrar otro proyecto',
    'Created by %s' => 'Creado por %s',
    'Tasks Export' => 'Exportar tareas',
    'Start Date' => 'Fecha de inicio',
    'Execute' => 'Ejecutar',
    'Task Id' => 'ID de tarea',
    'Creator' => 'Creador',
    'Modification date' => 'Fecha de modificación',
    'Completion date' => 'Fecha de finalización',
    'Clone' => 'Clonar',
    'Project cloned successfully.' => 'Proyecto clonado correctamente',
    'Unable to clone this project.' => 'Impsible clonar proyecto',
    'Enable email notifications' => 'Habilitar notificaciones por correo electrónico',
    'Task position:' => 'Posición de la tarea',
    'The task #%d has been opened.' => 'La tarea #%d ha sido abierta',
    'The task #%d has been closed.' => 'La tarea #%d ha sido cerrada',
    'Sub-task updated' => 'Subtarea actualizada',
    'Title:' => 'Título:',
    'Status:' => 'Estado:',
    'Assignee:' => 'Asignada a:',
    'Time tracking:' => 'Control de tiempo:',
    'New sub-task' => 'Nueva subtarea',
    'New attachment added "%s"' => 'Nuevo adjunto agregado "%s"',
    'New comment posted by %s' => 'Nuevo comentario agregado por %s',
    'New comment' => 'Nuevo comentario',
    'Comment updated' => 'Comentario actualizado',
    'New subtask' => 'Nueva subtarea',
    'I only want to receive notifications for these projects:' => 'Quiero recibir notificaciones sólo de estos proyectos:',
    'view the task on Kanboard' => 'ver la tarea en Kanboard',
    'Public access' => 'Acceso público',
    'Disable public access' => 'Desactivar acceso público',
    'Enable public access' => 'Activar acceso público',
    'Public access disabled' => 'Acceso público desactivado',
    'Move the task to another project' => 'Mover la tarea a otro proyecto',
    'Move to project' => 'Mover a otro proyecto',
    'Do you really want to duplicate this task?' => '¿Realmente quiere duplicar esta tarea?',
    'Duplicate a task' => 'Duplicar una tarea',
    'External accounts' => 'Cuentas externas',
    'Account type' => 'Tipo de Cuenta',
    'Local' => 'Local',
    'Remote' => 'Remota',
    'Enabled' => 'Activada',
    'Disabled' => 'Desactivada',
    'Login:' => 'Login:',
    'Full Name:' => 'Nombre completo:',
    'Email:' => 'Correo electrónico:',
    'Notifications:' => 'Notificaciones:',
    'Notifications' => 'Notificaciones',
    'Account type:' => 'Tipo de Cuenta:',
    'Edit profile' => 'Editar perfil',
    'Change password' => 'Cambiar contraseña',
    'Password modification' => 'Modificacion de contraseña',
    'External authentications' => 'Autenticación externa',
    'Never connected.' => 'Nunca se ha conectado.',
    'No external authentication enabled.' => 'Sin autenticación externa activa.',
    'Password modified successfully.' => 'Contraseña cambiada correctamente.',
    'Unable to change the password.' => 'No pude cambiar la contraseña.',
    'Change category' => 'Cambiar categoría',
    '%s updated the task %s' => '%s actualizó la tarea %s',
    '%s opened the task %s' => '%s abrió la tarea %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s movió la tarea %s a la posición #%d de la columna "%s"',
    '%s moved the task %s to the column "%s"' => '%s movió la tarea %s a la columna "%s"',
    '%s created the task %s' => '%s creó la tarea %s',
    '%s closed the task %s' => '%s cerró la tarea %s',
    '%s created a subtask for the task %s' => '%s creó una subtarea para la tarea %s',
    '%s updated a subtask for the task %s' => '%s actualizó una subtarea para la tarea %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Asignada a %s con una estimación de %s/%sh',
    'Not assigned, estimate of %sh' => 'No asignada, se estima en %sh',
    '%s updated a comment on the task %s' => '%s actualizó un comentario de la tarea %s',
    '%s commented the task %s' => '%s comentó la tarea %s',
    '%s\'s activity' => 'Actividad de %s',
    'RSS feed' => 'Archivo RSS',
    '%s updated a comment on the task #%d' => '%s actualizó un comentario de la tarea #%d',
    '%s commented on the task #%d' => '%s comentó la tarea #%d',
    '%s updated a subtask for the task #%d' => '%s actualizó una subtarea de la tarea #%d',
    '%s created a subtask for the task #%d' => '%s creó una subtarea de la tarea #%d',
    '%s updated the task #%d' => '%s actualizó la tarea #%d',
    '%s created the task #%d' => '%s creó la tarea #%d',
    '%s closed the task #%d' => '%s cerró la tarea #%d',
    '%s opened the task #%d' => '%s abrió la tarea #%d',
    'Activity' => 'Actividad',
    'Default values are "%s"' => 'Los valores por defecto son "%s"',
    'Default columns for new projects (Comma-separated)' => 'Columnas por defecto de los nuevos proyectos (Separadas mediante comas)',
    'Task assignee change' => 'Cambiar persona asignada a la tarea',
    '%s changed the assignee of the task #%d to %s' => '%s cambió al asignado de la tarea #%d a %s',
    '%s changed the assignee of the task %s to %s' => '%s cambió la persona asignada de la tarea de %s a %s',
    'New password for the user "%s"' => 'Nueva contraseña para el usuario(a) "%s"',
    'Choose an event' => 'Seleccione un evento',
    'Create a task from an external provider' => 'Crear una tarea a partir de un proveedor externo',
    'Change the assignee based on an external username' => 'Cambiar la asignación basado en un nombre de usuario(a) externo',
    'Change the category based on an external label' => 'Cambiar la categoría basado en una etiqueta externa',
    'Reference' => 'Referencia',
    'Label' => 'Etiqueta',
    'Database' => 'Base de Datos',
    'About' => 'Acerca de',
    'Database driver:' => 'Controlador de la base de datos',
    'Board settings' => 'Configuraciones del Tablero',
    'Webhook settings' => 'Configuraciones del Webhook',
    'Reset token' => 'Reiniciar token',
    'API endpoint:' => 'Punto extremo del API',
    'Refresh interval for personal board' => 'Intervalo de refrescamiento del tablero privado',
    'Refresh interval for public board' => 'Intervalo de refrescamiento del tablero público',
    'Task highlight period' => 'Período del realce de la tarea',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Periodo (en segundos) para considerar que una tarea fue modificada recientemente (0 para deshabilitar, 2 días por defecto)',
    'Frequency in second (60 seconds by default)' => 'Frecuencia en segundos (60 segundos por defecto)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frecuencia en segundos (0 para deshabilitar esta característica, 10 segundos por defecto)',
    'Application URL' => 'URL de la aplicación',
    'Token regenerated.' => 'Token regenerado',
    'Date format' => 'Formato de la fecha',
    'ISO format is always accepted, example: "%s" and "%s"' => 'El formato ISO siempre es aceptado, ejemplo: "%s" y "%s"',
    'New personal project' => 'Nuevo proyecto privado',
    'This project is personal' => 'Este proyecto es privado',
    'Add' => 'Añadir',
    'Start date' => 'Fecha de inicio',
    'Time estimated' => 'Horas presupuestadas',
    'There is nothing assigned to you.' => 'Nada asignado para usted',
    'My tasks' => 'Mis tareas',
    'Activity stream' => 'Flujo de actividades',
    'Dashboard' => 'Tablero',
    'Confirmation' => 'Confirmación',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Crear un comentario a partir de un proveedor externo',
    'Project management' => 'Gestión de proyectos',
    'Columns' => 'Columnas',
    'Task' => 'Tarea',
    'Percentage' => 'Porcentaje',
    'Number of tasks' => 'Número de tareas',
    'Task distribution' => 'Distribución de tareas',
    'Analytics' => 'Analítica',
    'Subtask' => 'Subtarea',
    'User repartition' => 'Usuario(a)s y su repartición de trabajo',
    'Clone this project' => 'Clonar este proyecto',
    'Column removed successfully.' => 'Columna removida correctamente',
    'Not enough data to show the graph.' => 'No hay suficiente información para mostrar el gráfico',
    'Previous' => 'Anterior',
    'The id must be an integer' => 'El identificador debe ser un número entero',
    'The project id must be an integer' => 'El identificador del proyecto debe ser un número entero',
    'The status must be an integer' => 'El estado debe ser un número entero',
    'The subtask id is required' => 'El identificador de la subtarea es requerido',
    'The subtask id must be an integer' => 'El identificador de la subtarea debe ser un número entero',
    'The task id is required' => 'El identificador de la tarea es requerido',
    'The task id must be an integer' => 'El identificador de la tarea debe ser un número entero',
    'The user id must be an integer' => 'El identificador del usuario(a) debe ser un número entero',
    'This value is required' => 'El valor es requerido',
    'This value must be numeric' => 'Este valor debe ser numérico',
    'Unable to create this task.' => 'Imposible crear esta tarea',
    'Cumulative flow diagram' => 'Diagrama de flujo acumulativo',
    'Daily project summary' => 'Resumen diario del proyecto',
    'Daily project summary export' => 'Exportar sumario diario del proyecto',
    'Exports' => 'Exportar',
    'This export contains the number of tasks per column grouped per day.' => 'Esta exportación contiene el número de tereas por columna agrupada por día',
    'Active swimlanes' => 'Carriles activos',
    'Add a new swimlane' => 'Añadir nuevo carril',
    'Default swimlane' => 'Carril por defecto',
    'Do you really want to remove this swimlane: "%s"?' => '¿Realmente quiere remover este carril: "%s"?',
    'Inactive swimlanes' => 'Carriles inactivos',
    'Remove a swimlane' => 'Remover un carril',
    'Swimlane modification for the project "%s"' => 'Modificación del carril para el proyecto "%s"',
    'Swimlane removed successfully.' => 'Carril removido correctamente',
    'Swimlanes' => 'Carriles',
    'Swimlane updated successfully.' => 'Carril actualizado correctamente',
    'Unable to remove this swimlane.' => 'Imposible remover este carril',
    'Unable to update this swimlane.' => 'Imposible actualizar este carril',
    'Your swimlane has been created successfully.' => 'Su carril ha sido creado correctamente',
    'Example: "Bug, Feature Request, Improvement"' => 'Ejemplo: "Error, Solicitud de característica, Mejora"',
    'Default categories for new projects (Comma-separated)' => 'Categorías por defecto de los nuevos proyectos (separadas mediante comas)',
    'Integrations' => 'Integraciones',
    'Integration with third-party services' => 'Integraciones para servicios de terceros',
    'Subtask Id' => 'Identificador de subtareas',
    'Subtasks' => 'Subtareas',
    'Subtasks Export' => 'Exportar subtareas',
    'Task Title' => 'Título de la tarea',
    'Untitled' => 'Sin título',
    'Application default' => 'Predefinido de la aplicación',
    'Language:' => 'Idioma',
    'Timezone:' => 'Zona horaria',
    'All columns' => 'Todas las columnas',
    'Next' => 'Siguiente',
    '#%d' => '#%d',
    'All swimlanes' => 'Todos los carriles',
    'All colors' => 'Todos los colores',
    'Moved to column %s' => 'Movido a columna %s',
    'User dashboard' => 'Tablero de el(la) usuario(a)',
    'Allow only one subtask in progress at the same time for a user' => 'Permitir únicamente una subtarea en progreso al mismo tiempo para un usuario(a)',
    'Edit column "%s"' => 'Editar columna "%s"',
    'Select the new status of the subtask: "%s"' => 'Seleccione el nuevo estado de la subtarea: "%s"',
    'Subtask timesheet' => 'Hoja de tiempos de la subtarea',
    'There is nothing to show.' => 'No hay nada que mostrar.',
    'Time Tracking' => 'Control de Tiempo',
    'You already have one subtask in progress' => 'Ya tiene una subtarea en progreso',
    'Which parts of the project do you want to duplicate?' => '¿Que partes del proyecto quiere duplicar?',
    'Disallow login form' => 'Deshabilitar el formulario de inicio de sesión',
    'Start' => 'Inicio',
    'End' => 'Fin',
    'Task age in days' => 'Tiempo de la tarea (en días)',
    'Days in this column' => 'Días en esta columna',
    '%dd' => '%dd',
    'Add a new link' => 'Añadir nuevo vínculo',
    'Do you really want to remove this link: "%s"?' => '¿Realmente quiere eliminar este vínculo: "%s"?',
    'Do you really want to remove this link with task #%d?' => '¿Realmente quiere eliminar este vínculo con la tarea #%d?',
    'Field required' => 'Campo requerido',
    'Link added successfully.' => 'Vínculo añadido correctamente',
    'Link updated successfully.' => 'Vínculo actualizado correctamente',
    'Link removed successfully.' => 'Vínculo suprimido correctamente',
    'Link labels' => 'Etiquetas de vínculos',
    'Link modification' => 'Modificar vínculo',
    'Opposite label' => 'Etiquetas opuestas',
    'Remove a link' => 'Suprimir un vínculo',
    'The labels must be different' => 'Las etiquetas deben ser diferentes',
    'There is no link.' => 'No hay vínculo',
    'This label must be unique' => 'Esta etiqueta debe ser única',
    'Unable to create your link.' => 'No se puede crear su vínculo',
    'Unable to update your link.' => 'No se puede actualizar su vínculo',
    'Unable to remove this link.' => 'No se puede suprimir su vínculo',
    'relates to' => 'relacionado con',
    'blocks' => 'bloqueos',
    'is blocked by' => 'esta bloqueado por',
    'duplicates' => 'duplicados',
    'is duplicated by' => 'está duplicado por',
    'is a child of' => 'es hijo de',
    'is a parent of' => 'es padre de',
    'targets milestone' => 'metas del hito',
    'is a milestone of' => 'es un hito de',
    'fixes' => 'arreglo',
    'is fixed by' => 'arreglado por',
    'This task' => 'Esta tarea',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Expandir tareas',
    'Collapse tasks' => 'Colapsar tareas',
    'Expand/collapse tasks' => 'Expandir/colapsar tareas',
    'Close dialog box' => 'Cerrar caudro de diálogo',
    'Submit a form' => 'Enviar un formulario',
    'Board view' => 'Vista de tablero',
    'Keyboard shortcuts' => 'Atajos del teclado',
    'Open board switcher' => 'Conmutador de tablero abierto',
    'Application' => 'Aplicación',
    'Compact view' => 'Vista compacta',
    'Horizontal scrolling' => 'Desplazamiento horizontal',
    'Compact/wide view' => 'Vista compacta/amplia',
    'Currency' => 'Moneda',
    'Personal project' => 'Proyecto privado',
    'AUD - Australian Dollar' => 'AUD - Dólar australiano',
    'CAD - Canadian Dollar' => 'CAD - Dólar canadiense',
    'CHF - Swiss Francs' => 'CHF - Franco suizo',
    'Custom Stylesheet' => 'Hoja de estilo personalizada',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Libra británica',
    'INR - Indian Rupee' => 'INR - Rupia india',
    'JPY - Japanese Yen' => 'JPY - Yen japonés',
    'NZD - New Zealand Dollar' => 'NZD - Dólar de Nueva Zelanda',
    'PEN - Peruvian Sol' => 'PEN - Sol peruano',
    'RSD - Serbian dinar' => 'RSD - Dinar serbio',
    'CNY - Chinese Yuan' => 'CNY - Yuan Chino',
    'USD - US Dollar' => 'USD - Dólar estadounidense',
    'VES - Venezuelan Bolívar' => 'VES - Bolívar Venezolano',
    'Destination column' => 'Columna destino',
    'Move the task to another column when assigned to a user' => 'Mover la tarea a otra columna cuando sea asignada a un usuario(a)',
    'Move the task to another column when assignee is cleared' => 'Mover la tarea a otra columna cuando se elimine la persona asignada',
    'Source column' => 'Columna de origen',
    'Transitions' => 'Transiciones',
    'Executer' => 'Ejecutor',
    'Time spent in the column' => 'Horas ejecutadas en la columna',
    'Task transitions' => 'Transiciones de las tareas',
    'Task transitions export' => 'Exportar transiciones de las tareas',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Este reporte contiene todos los movimientos de columna por cada tarea con la fecha, el(la) usuario(a) y el tiempo transcurrido para cada transición',
    'Currency rates' => 'Tipos de cambio',
    'Rate' => 'Tarifa',
    'Change reference currency' => 'Cambiar moneda de referencia',
    'Reference currency' => 'Moneda de referencia',
    'The currency rate has been added successfully.' => 'El tipo de cambio ha sido añadido correctamente.',
    'Unable to add this currency rate.' => 'No se puede añadir este tipo de cambio.',
    'Webhook URL' => 'URL del Webhook',
    '%s removed the assignee of the task %s' => '%s eliminó al asignado de la tarea %s',
    'Information' => 'Información',
    'Check two factor authentication code' => 'Verificar el código de autenticación de dos factores',
    'The two factor authentication code is not valid.' => 'El código de autenticación de dos factores no es válido',
    'The two factor authentication code is valid.' => 'El código de autenticación de dos factores es válido',
    'Code' => 'Código',
    'Two factor authentication' => 'Autenticación de dos factores',
    'This QR code contains the key URI: ' => 'Este código QR contiene la clave URI: ',
    'Check my code' => 'Verificar mi código',
    'Secret key: ' => 'Clave secreta: ',
    'Test your device' => 'Pruebe su dispositivo',
    'Assign a color when the task is moved to a specific column' => 'Asignar un color cuando la tarea se mueve a una columna específica',
    '%s via Kanboard' => '%s vía Kanboard',
    'Burndown chart' => 'Gráfico de Tareas Pendientes',
    'This chart show the task complexity over the time (Work Remaining).' => 'Este gráfico muestra la complejidad de la tarea durante el tiempo (Trabajo restante)',
    'Screenshot taken %s' => 'Captura de pantalla tomada %s',
    'Add a screenshot' => 'Añadir una captura de pantalla',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Tomar una captura de pantalla y presione CTRL+V o ⌘+V para pegar aquí.',
    'Screenshot uploaded successfully.' => 'Captura de pantalla subida correctamente',
    'SEK - Swedish Krona' => 'SEK - Corona sueca',
    'Identifier' => 'Identificador',
    'Disable two factor authentication' => 'Deshabilitar la autenticación de dos factores',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => '¿Realmente desea desactivar la autenticación de dos factores para este usuario(a): "%s"?',
    'Edit link' => 'Editar enlace',
    'Start to type task title...' => 'Comenzar a escribir el título de la tarea ...',
    'A task cannot be linked to itself' => 'Una tarea no se puede vincular a sí misma',
    'The exact same link already exists' => 'Ya existe un enlace idéntico',
    'Recurrent task is scheduled to be generated' => 'La tarea periódica está programada para ser generada',
    'Score' => 'Puntuación',
    'The identifier must be unique' => 'El identificador debe ser único',
    'This linked task id doesn\'t exists' => 'El identificador de la tarea enlazada no existe',
    'This value must be alphanumeric' => 'Este valor debe ser alfanumérico',
    'Edit recurrence' => 'Editar recurrencia',
    'Generate recurrent task' => 'Generar tarea recurrente',
    'Trigger to generate recurrent task' => 'Disparador para generar tarea recurrente',
    'Factor to calculate new due date' => 'Factor para calcular la nueva fecha de vencimiento',
    'Timeframe to calculate new due date' => 'Plazo para calcular la nueva fecha de vencimiento',
    'Base date to calculate new due date' => 'Fecha base para calcular la nueva fecha de vencimiento',
    'Action date' => 'Fecha de acción',
    'Base date to calculate new due date: ' => 'Fecha base para calcular la nueva fecha de vencimiento: ',
    'This task has created this child task: ' => 'Esta tarea ha creado esta tarea hija: ',
    'Day(s)' => 'Día(s)',
    'Existing due date' => 'Fecha de vencimiento existente',
    'Factor to calculate new due date: ' => 'Factor para calcular la nueva fecha de vencimiento: ',
    'Month(s)' => 'Mes(es)',
    'This task has been created by: ' => 'Esta tarea ha sido creada por: ',
    'Recurrent task has been generated:' => 'Se ha generado una tarea recurrente:',
    'Timeframe to calculate new due date: ' => 'Plazo para calcular la nueva fecha de vencimiento: ',
    'Trigger to generate recurrent task: ' => 'Disparador para generar la tarea recurrente: ',
    'When task is closed' => 'Cuando la tarea está cerrada',
    'When task is moved from first column' => 'Cuando se mueve la tarea desde la primera columna',
    'When task is moved to last column' => 'Cuando la tarea se mueve a la última columna',
    'Year(s)' => 'Año(s)',
    'Project settings' => 'Configuración del proyecto',
    'Automatically update the start date' => 'Actualizar automáticamente la fecha de inicio',
    'iCal feed' => 'Alimentador de iCal',
    'Preferences' => 'Preferencias',
    'Security' => 'Seguridad',
    'Two factor authentication disabled' => 'Se ha inhabilitado la autenticación de dos factores.',
    'Two factor authentication enabled' => 'Autenticación de dos factores habilitada',
    'Unable to update this user.' => 'No se puede actualizar este usuario(a).',
    'There is no user management for personal projects.' => 'No hay gestión de usuario(a)s para proyectos privados.',
    'User that will receive the email' => 'Usuario(a) que recibirá el correo electrónico',
    'Email subject' => 'Asunto del correo electrónico',
    'Date' => 'Fecha',
    'Add a comment log when moving the task between columns' => 'Añadir un registro en los comentarios al mover la tarea entre columnas',
    'Move the task to another column when the category is changed' => 'Mover la tarea a otra columna cuando se cambia la categoría',
    'Send a task by email to someone' => 'Enviar una tarea por correo electrónico a alguien',
    'Reopen a task' => 'Reabrir una tarea',
    'Notification' => 'Notificación',
    '%s moved the task #%d to the first swimlane' => '%s movió la tarea #%d al primer carril',
    'Swimlane' => 'Carril',
    '%s moved the task %s to the first swimlane' => '%s movió la tarea %s al primer carril',
    '%s moved the task %s to the swimlane "%s"' => '%s trasladó la tarea %s al carril "%s"',
    'This report contains all subtasks information for the given date range.' => 'Este informe contiene toda la información de las subtareas para el intervalo de fechas especificado.',
    'This report contains all tasks information for the given date range.' => 'Este informe contiene la información de todas las tareas para el intervalo de fechas dado.',
    'Project activities for %s' => 'Actividades del proyecto para %s',
    'view the board on Kanboard' => 'ver el tablero en Kanboard',
    'The task has been moved to the first swimlane' => 'La tarea se ha movido al primer carril',
    'The task has been moved to another swimlane:' => 'La tarea se ha trasladado a otro carril:',
    'New title: %s' => 'Nuevo título: %s',
    'The task is not assigned anymore' => 'La tarea ya no está asignada',
    'New assignee: %s' => 'Nuevo asignado: %s',
    'There is no category now' => 'No hay categoría ahora',
    'New category: %s' => 'Nueva categoría: %s',
    'New color: %s' => 'Nuevo color: %s',
    'New complexity: %d' => 'Nueva complejidad: %d',
    'The due date has been removed' => 'Se ha eliminado la fecha de vencimiento',
    'There is no description anymore' => 'Ya no hay ninguna descripción',
    'Recurrence settings has been modified' => 'Los parámetros de recurrencia se han modificado',
    'Time spent changed: %sh' => 'Tiempo ejecutado cambiado: %sh',
    'Time estimated changed: %sh' => 'Horas Presupuestadas cambiado: %sh',
    'The field "%s" has been updated' => 'Se ha actualizado el campo "%s"',
    'The description has been modified:' => 'La descripción ha sido modificada:',
    'Do you really want to close the task "%s" as well as all subtasks?' => '¿Realmente desea cerrar la tarea "%s", así como todas sus subtareas?',
    'I want to receive notifications for:' => 'Quiero recibir notificaciones para:',
    'All tasks' => 'Todas las tareas',
    'Only for tasks assigned to me' => 'Sólo para tareas asignadas a mí',
    'Only for tasks created by me' => 'Sólo para tareas creadas por mí',
    'Only for tasks created by me and tasks assigned to me' => 'Sólo para las tareas creadas por mí y asignadas a mí',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Total para todas las columnas',
    'You need at least 2 days of data to show the chart.' => 'Necesita al menos 2 días de datos para mostrar el gráfico.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Detener temporizador',
    'Start timer' => 'Iniciar el temporizador',
    'My activity stream' => 'Mi flujo de actividad',
    'Search tasks' => 'Buscar tareas',
    'Reset filters' => 'Restablecer filtros',
    'My tasks due tomorrow' => 'Mis tareas para mañana',
    'Tasks due today' => 'Tareas pendientes hoy',
    'Tasks due tomorrow' => 'Tareas para mañana',
    'Tasks due yesterday' => 'Tareas vencidas ayer',
    'Closed tasks' => 'Tareas cerradas',
    'Open tasks' => 'Tareas abiertas',
    'Not assigned' => 'No asignado',
    'View advanced search syntax' => 'Ver sintaxis de búsqueda avanzada',
    'Overview' => 'Visión general',
    'Board/Calendar/List view' => 'Vista de Tablero/Calendario/Lista',
    'Switch to the board view' => 'Cambiar a la vista de tablero',
    'Switch to the list view' => 'Cambiar a la vista de lista',
    'Go to the search/filter box' => 'Ir a la caja de búsqueda/filtro',
    'There is no activity yet.' => 'No hay actividad todavía.',
    'No tasks found.' => 'No se han encontrado tareas.',
    'Keyboard shortcut: "%s"' => 'Atajo de teclado: "%s"',
    'List' => 'Lista',
    'Filter' => 'Filtrar',
    'Advanced search' => 'Búsqueda Avanzada',
    'Example of query: ' => 'Ejemplo de consulta: ',
    'Search by project: ' => 'Buscar por proyecto: ',
    'Search by column: ' => 'Buscar por columna: ',
    'Search by assignee: ' => 'Buscar por asignado:',
    'Search by color: ' => 'Buscar por color: ',
    'Search by category: ' => 'Buscar por categoría: ',
    'Search by description: ' => 'Buscar por descripción: ',
    'Search by due date: ' => 'Buscar por fecha de vencimiento: ',
    'Average time spent in each column' => 'Tiempo de permanencia promedio en cada columna',
    'Average time spent' => 'Tiempo ejecutado promedio',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Este gráfico muestra el tiempo promedio invertido en cada columna para las últimas %d tareas.',
    'Average Lead and Cycle time' => 'Tiempo de Espera y de Ciclo promedio',
    'Average lead time: ' => 'Tiempo de espera promedio: ',
    'Average cycle time: ' => 'Tiempo del ciclo promedio: ',
    'Cycle Time' => 'Tiempo del Ciclo',
    'Lead Time' => 'Tiempo de Espera',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Este gráfico muestra el tiempo promedio de espera y de ciclo para las últimas %d tareas.',
    'Average time into each column' => 'Tiempo promedio en cada columna',
    'Lead and cycle time' => 'Tiempo de espera y de ciclo',
    'Lead time: ' => 'Tiempo de Espera: ',
    'Cycle time: ' => 'Tiempo del Ciclo: ',
    'Time spent in each column' => 'Tiempo empleado en cada columna',
    'The lead time is the duration between the task creation and the completion.' => 'El tiempo de espera es la duración entre la creación de la tarea y la finalización.',
    'The cycle time is the duration between the start date and the completion.' => 'El tiempo de ciclo es la duración entre la fecha de inicio y la finalización.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Si la tarea no está cerrada, se utiliza la hora actual en lugar de la fecha de finalización.',
    'Set the start date automatically' => 'Establecer automáticamente la fecha de inicio',
    'Edit Authentication' => 'Editar autenticación',
    'Remote user' => 'Usuario(a) remoto',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Los usuario(a)s remotos no almacenan su contraseña en la base de datos Kanboard, ejemplos: cuentas LDAP, Google y Github.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Si marca la casilla "Deshabilitar el formulario de inicio de sesión", las credenciales ingresadas en el formulario de inicio de sesión serán ignoradas.',
    'Default task color' => 'Color predeterminado de la tarea',
    'This feature does not work with all browsers.' => 'Esta función no funciona con todos los navegadores.',
    'There is no destination project available.' => 'No hay proyecto de destino disponible.',
    'Trigger automatically subtask time tracking' => 'Activar automáticamente el seguimiento de tiempo de la subtarea',
    'Include closed tasks in the cumulative flow diagram' => 'Incluir tareas cerradas en el diagrama de flujo acumulativo',
    'Current swimlane: %s' => 'Carril actual: %s',
    'Current column: %s' => 'Columna actual: %s',
    'Current category: %s' => 'Categoría actual: %s',
    'no category' => 'sin categoria',
    'Current assignee: %s' => 'Asignado actual: %s',
    'not assigned' => 'no asignado',
    'Author:' => 'Autor:',
    'contributors' => 'colaboradores',
    'License:' => 'Licencia:',
    'License' => 'Licencia',
    'Enter the text below' => 'Introduzca el texto a continuación',
    'Start date:' => 'Fecha de inicio:',
    'Due date:' => 'Fecha de vencimiento:',
    'People who are project managers' => 'Personas que son gerentes de proyecto',
    'People who are project members' => 'Personas que son miembros del proyecto',
    'NOK - Norwegian Krone' => 'NOK - Corona Noruega',
    'Show this column' => 'Mostrar esta columna',
    'Hide this column' => 'Ocultar esta columna',
    'End date' => 'Fecha final',
    'Users overview' => 'Visión general de los usuario(a)s',
    'Members' => 'Miembros',
    'Shared project' => 'Proyecto compartido',
    'Project managers' => 'Gerentes de Proyecto',
    'Projects list' => 'Lista de proyectos',
    'End date:' => 'Fecha final:',
    'Change task color when using a specific task link' => 'Cambiar el color de la tarea cuando se utiliza un enlace de tarea específico',
    'Task link creation or modification' => 'Creación o modificación de enlaces de tareas',
    'Milestone' => 'Hito',
    'Reset the search/filter box' => 'Restablecer la caja de búsqueda/filtro',
    'Documentation' => 'Documentación',
    'Author' => 'Autor',
    'Version' => 'Versión',
    'Plugins' => 'Complementos',
    'There is no plugin loaded.' => 'No hay ningún complemento cargado.',
    'My notifications' => 'Mis Notificaciones',
    'Custom filters' => 'Filtros personalizados',
    'Your custom filter has been created successfully.' => 'Su filtro personalizado se ha creado correctamente.',
    'Unable to create your custom filter.' => 'No se puede crear el filtro personalizado.',
    'Custom filter removed successfully.' => 'Filtro personalizado eliminado correctamente.',
    'Unable to remove this custom filter.' => 'No se puede quitar este filtro personalizado.',
    'Edit custom filter' => 'Editar filtro personalizado',
    'Your custom filter has been updated successfully.' => 'Su filtro personalizado se ha actualizado correctamente.',
    'Unable to update custom filter.' => 'No se puede actualizar el filtro personalizado.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Nuevo archivo adjunto en la tarea #%d: %s',
    'New comment on task #%d' => 'Nuevo comentario sobre la tarea #%d',
    'Comment updated on task #%d' => 'Comentario actualizado en la tarea #%d',
    'New subtask on task #%d' => 'Nueva subtarea en la tarea #%d',
    'Subtask updated on task #%d' => 'Subtarea actualizada en la tarea #%d',
    'New task #%d: %s' => 'Nueva tarea #%d: %s',
    'Task updated #%d' => 'Tarea actualizada #%d',
    'Task #%d closed' => 'Tarea #%d cerrada',
    'Task #%d opened' => 'Tarea #%d abierta',
    'Column changed for task #%d' => 'Columna modificada para la tarea #%d',
    'New position for task #%d' => 'Nueva posición para la tarea #%d',
    'Swimlane changed for task #%d' => 'Carril cambiado para la tarea #%d',
    'Assignee changed on task #%d' => 'Asignado cambiado en la tarea #%d',
    '%d overdue tasks' => '%d tareas pendientes',
    'No notification.' => 'Sin notificación.',
    'Mark all as read' => 'marcar todo como leido',
    'Mark as read' => 'Marcar como leído',
    'Total number of tasks in this column across all swimlanes' => 'Número total de tareas en esta columna contando todos los carriles',
    'Collapse swimlane' => 'Colapsar el carril',
    'Expand swimlane' => 'Expandir el carril',
    'Add a new filter' => 'Añadir un nuevo filtro',
    'Share with all project members' => 'Compartir con todos los miembros del proyecto',
    'Shared' => 'Compartido',
    'Owner' => 'Propietario',
    'Unread notifications' => 'Notificaciones no leídas',
    'Notification methods:' => 'Métodos de notificación:',
    'Unable to read your file' => 'No se puede leer el archivo',
    '%d task(s) have been imported successfully.' => '%d tarea(s) se han importado correctamente.',
    'Nothing has been imported!' => '¡Ningún dato importado!',
    'Import users from CSV file' => 'Importar usuario(a)s de un archivo CSV (valores separados por comas)',
    '%d user(s) have been imported successfully.' => '%d usuario(s) se han importado correctamente.',
    'Comma' => 'Coma',
    'Semi-colon' => 'Punto y coma',
    'Tab' => 'Tabulación',
    'Vertical bar' => 'Barra vertical',
    'Double Quote' => 'Comillas dobles',
    'Single Quote' => 'Comillas simples',
    '%s attached a file to the task #%d' => '%s adjuntó un archivo a la tarea #%d',
    'There is no column or swimlane activated in your project!' => '¡No hay columna ni carril activado en tu proyecto!',
    'Append filter (instead of replacement)' => 'Agregar el filtro (en lugar del reemplazo)',
    'Append/Replace' => 'Añadir/Reemplazar',
    'Append' => 'Adjuntar',
    'Replace' => 'Reemplazar',
    'Import' => 'Importar',
    'Change sorting' => 'Cambio de orden',
    'Tasks Importation' => 'Importación de Tareas',
    'Delimiter' => 'Delimitador',
    'Enclosure' => 'Contenedor',
    'CSV File' => 'Archivo CSV',
    'Instructions' => 'Instrucciones',
    'Your file must use the predefined CSV format' => 'Su archivo debe utilizar el formato CSV predefinido',
    'Your file must be encoded in UTF-8' => 'Su archivo debe estar codificado en UTF-8',
    'The first row must be the header' => 'La primera fila debe ser el encabezado',
    'Duplicates are not verified for you' => 'Los duplicados no se verifican',
    'The due date must use the ISO format: YYYY-MM-DD' => 'La fecha de vencimiento debe utilizar el formato ISO: AAAA-MM-DD',
    'Download CSV template' => 'Descargar plantilla CSV',
    'No external integration registered.' => 'No se ha registrado ninguna integración externa.',
    'Duplicates are not imported' => 'Los duplicados no se importan',
    'Usernames must be lowercase and unique' => 'Los nombres de usuario(a) deben estar en minúsculas y ser únicos',
    'Passwords will be encrypted if present' => 'Las contraseñas se cifrarán si están presentes',
    '%s attached a new file to the task %s' => '%s adjunto un nuevo archivo a la tarea %s',
    'Link type' => 'Tipo de enlace',
    'Assign automatically a category based on a link' => 'Asignar automáticamente una categoría basada en un enlace',
    'BAM - Konvertible Mark' => 'BAM - Marco Convertible',
    'Assignee Username' => 'Usuario(a) asignado',
    'Assignee Name' => 'Nombre del asignado',
    'Groups' => 'Grupos',
    'Members of %s' => 'Miembros de %s',
    'New group' => 'Nuevo grupo',
    'Group created successfully.' => 'Grupo creado correctamente.',
    'Unable to create your group.' => 'No se puede crear su grupo.',
    'Edit group' => 'Editar grupo',
    'Group updated successfully.' => 'Grupo actualizado correctamente.',
    'Unable to update your group.' => 'No se puede actualizar su grupo.',
    'Add group member to "%s"' => 'Agregue el miembro del grupo a "%s"',
    'Group member added successfully.' => 'Miembro del grupo agregado correctamente.',
    'Unable to add group member.' => 'No se puede agregar el miembro del grupo.',
    'Remove user from group "%s"' => 'Quitar usuario del grupo "%s"',
    'User removed successfully from this group.' => 'Usuario(a) eliminadov correctamente de este grupo.',
    'Unable to remove this user from the group.' => 'No se puede eliminar este usuario(a) del grupo.',
    'Remove group' => 'Eliminar grupo',
    'Group removed successfully.' => 'Grupo eliminado correctamente.',
    'Unable to remove this group.' => 'No se pudo eliminar este grupo.',
    'Project Permissions' => 'Permisos del proyecto',
    'Manager' => 'Gerente',
    'Project Manager' => 'Gerente de proyecto',
    'Project Member' => 'Miembro del proyecto',
    'Project Viewer' => 'Visor de proyectos',
    'Your account is locked for %d minutes' => 'Tu cuenta está bloqueada durante %d minutos',
    'Invalid captcha' => 'CAPTCHA inválido',
    'The name must be unique' => 'El nombre debe ser único',
    'View all groups' => 'Ver todos los grupos',
    'There is no user available.' => 'No hay usuario(a)s disponibles.',
    'Do you really want to remove the user "%s" from the group "%s"?' => '¿Realmente desea eliminar el(la) usuario(a) "%s" del grupo "%s"?',
    'There is no group.' => 'No hay grupo.',
    'Add group member' => 'Agregar miembro del grupo',
    'Do you really want to remove this group: "%s"?' => '¿Desea realmente eliminar este grupo: "%s"?',
    'There is no user in this group.' => 'No hay ningún usuario(a) en este grupo.',
    'Permissions' => 'Permisos',
    'Allowed Users' => 'Usuario(a)s permitidos',
    'No specific user has been allowed.' => 'Ningún usuario(a) ha sido autorizado específicamente.',
    'Role' => 'Rol',
    'Enter user name...' => 'Introduzca su nombre de usuario(a)...',
    'Allowed Groups' => 'Grupos permitidos',
    'No group has been allowed.' => 'Ningún grupo se ha permitido específicamente.',
    'Group' => 'Grupo',
    'Group Name' => 'Nombre del grupo',
    'Enter group name...' => 'Introduzca el nombre del grupo ...',
    'Role:' => 'Rol:',
    'Project members' => 'Miembros del proyecto',
    '%s mentioned you in the task #%d' => '%s te mencionó en la tarea #%d',
    '%s mentioned you in a comment on the task #%d' => '%s te ha mencionado en un comentario sobre la tarea #%d',
    'You were mentioned in the task #%d' => 'Te mencionaron en la tarea #%d',
    'You were mentioned in a comment on the task #%d' => 'Usted fue mencionado en un comentario en la tarea #%d',
    'Estimated hours: ' => 'Horas estimadas: ',
    'Actual hours: ' => 'Horas reales: ',
    'Hours Spent' => 'Horas Gastadas',
    'Hours Estimated' => 'Horas Estimadas',
    'Estimated Time' => 'Tiempo Estimado',
    'Actual Time' => 'Tiempo Real',
    'Estimated vs actual time' => 'Horas Presupuestadas vs. tiempo real',
    'RUB - Russian Ruble' => 'RUB - Rublo Ruso',
    'Assign the task to the person who does the action when the column is changed' => 'Asigne la tarea a la persona que realiza la acción cuando se cambia la columna',
    'Close a task in a specific column' => 'Cerrar una tarea en una columna específica',
    'Time-based One-time Password Algorithm' => 'Algoritmo de contraseña de una sola vez basado en el tiempo',
    'Two-Factor Provider: ' => 'Proveedor de dos factores: ',
    'Disable two-factor authentication' => 'Deshabilitar la autenticación de dos factores',
    'Enable two-factor authentication' => 'Habilitar la autenticación de dos factores',
    'There is no integration registered at the moment.' => 'No hay ninguna integración registrada en este momento.',
    'Password Reset for Kanboard' => 'Restablecer contraseña para Kanboard',
    'Forgot password?' => '¿Olvidó su contraseña?',
    'Enable "Forget Password"' => 'Habilitar "Olvidar contraseña"',
    'Password Reset' => 'Restablecimiento de contraseña',
    'New password' => 'Nueva contraseña',
    'Change Password' => 'Cambiar la contraseña',
    'To reset your password click on this link:' => 'Para restablecer su contraseña, haga clic en este enlace:',
    'Last Password Reset' => 'Restablecer la última contraseña',
    'The password has never been reinitialized.' => 'La contraseña nunca ha sido reinicializada.',
    'Creation' => 'Creación',
    'Expiration' => 'Vencimiento',
    'Password reset history' => 'Historial de restablecimiento de contraseñas',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Todas las tareas de la columna "%s" y el carril "%s" han sido cerradas con éxito.',
    'Do you really want to close all tasks of this column?' => '¿Realmente desea cerrar todas las tareas de esta columna?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d tarea(s) en la columna "%s" y el carril "%s" se cerrará.',
    'Close all tasks in this column and this swimlane' => 'Cierre todas las tareas de esta columna',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Ningún plugin ha registrado un método de notificación de proyecto. Todavía puede configurar notificaciones individuales en su perfil de usuario(a).',
    'My dashboard' => 'Mi tablero',
    'My profile' => 'Mi perfil',
    'Project owner: ' => 'Propietario del proyecto: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'El identificador del proyecto es opcional y debe ser alfanumérico, por ejemplo: MIPROYECTO.',
    'Project owner' => 'Propietario del proyecto',
    'Personal projects do not have users and groups management.' => 'Los proyectos privados no tienen gestión de usuario(a)s y grupos.',
    'There is no project member.' => 'No hay ningún miembro del proyecto.',
    'Priority' => 'Prioridad',
    'Task priority' => 'Prioridad de la tarea',
    'General' => 'General',
    'Dates' => 'Fechas',
    'Default priority' => 'Prioridad predeterminada',
    'Lowest priority' => 'Menor prioridad',
    'Highest priority' => 'Mayor prioridad',
    'Close a task when there is no activity' => 'Cierra una tarea cuando no hay actividad',
    'Duration in days' => 'Duración en días',
    'Send email when there is no activity on a task' => 'Enviar correo electrónico cuando no hay actividad en una tarea',
    'Unable to fetch link information.' => 'No es posible obtener información de enlace.',
    'Daily background job for tasks' => 'Trabajo en segundo plano diario para las tareas',
    'Auto' => 'Auto',
    'Related' => 'Relacionado',
    'Attachment' => 'Archivo adjunto',
    'Web Link' => 'Enlace web',
    'External links' => 'Enlaces externos',
    'Add external link' => 'Añadir enlace externo',
    'Type' => 'Tipo',
    'Dependency' => 'Dependencia',
    'Add internal link' => 'Añadir enlace interno',
    'Add a new external link' => 'Añadir un nuevo enlace externo',
    'Edit external link' => 'Editar enlace externo',
    'External link' => 'Enlace externo',
    'Copy and paste your link here...' => 'Copia y pega el enlace aquí ...',
    'URL' => 'URL',
    'Internal links' => 'Enlaces internos',
    'Assign to me' => 'Asignármelo',
    'Me' => 'Yo',
    'Do not duplicate anything' => 'No duplique nada',
    'Projects management' => 'Gestión de proyectos',
    'Users management' => 'Gestión de usuario(a)s',
    'Groups management' => 'Gestión de grupos',
    'Create from another project' => 'Crear desde otro proyecto',
    'open' => 'abierto',
    'closed' => 'cerrado',
    'Priority:' => 'Prioridad:',
    'Reference:' => 'Referencia:',
    'Complexity:' => 'Complejidad:',
    'Swimlane:' => 'Carril:',
    'Column:' => 'Columna:',
    'Position:' => 'Posición:',
    'Creator:' => 'Creador:',
    'Time estimated:' => 'Horas Presupuestadas:',
    '%s hours' => '%s horas',
    'Time spent:' => 'Tiempo usado:',
    'Created:' => 'Creado:',
    'Modified:' => 'Modificado:',
    'Completed:' => 'Terminado:',
    'Started:' => 'Empezado:',
    'Moved:' => 'Movido:',
    'Task #%d' => 'Tarea número %d',
    'Time format' => 'Formato de tiempo',
    'Start date: ' => 'Fecha de inicio: ',
    'End date: ' => 'Fecha final: ',
    'New due date: ' => 'Nueva fecha de vencimiento: ',
    'Start date changed: ' => 'Fecha de inicio cambiada: ',
    'Disable personal projects' => 'Inhabilitar proyectos privados',
    'Do you really want to remove this custom filter: "%s"?' => '¿Desea realmente eliminar este filtro personalizado: "%s"?',
    'Remove a custom filter' => 'Eliminar un filtro personalizado',
    'User activated successfully.' => 'Usuario(a) activado correctamente.',
    'Unable to enable this user.' => 'No se puede habilitar este usuario(a).',
    'User disabled successfully.' => 'El usuario(a) ha sido desactivado correctamente.',
    'Unable to disable this user.' => 'No se puede deshabilitar este usuario(a).',
    'All files have been uploaded successfully.' => 'Todos los archivos se han cargado correctamente.',
    'The maximum allowed file size is %sB.' => 'El tamaño máximo de archivo permitido es %sB.',
    'Drag and drop your files here' => 'Arrastra y suelta tus archivos aquí',
    'choose files' => 'Elija el archivo',
    'View profile' => 'Ver perfil',
    'Two Factor' => 'Dos factores',
    'Disable user' => 'Deshabilitar usuario(a)',
    'Do you really want to disable this user: "%s"?' => '¿Desea realmente desactivar este usuario(a): "%s"?',
    'Enable user' => 'Habilitar usuario(a)',
    'Do you really want to enable this user: "%s"?' => '¿De verdad quieres habilitar a este usuario(a): "%s"?',
    'Download' => 'Descargar',
    'Uploaded: %s' => 'Subido: %s',
    'Size: %s' => 'Tamaño: %s',
    'Uploaded by %s' => 'Subido por %s',
    'Filename' => 'Nombre del archivo',
    'Size' => 'Tamaño',
    'Column created successfully.' => 'Columna creada correctamente.',
    'Another column with the same name exists in the project' => 'Otra columna con el mismo nombre existe en el proyecto',
    'Default filters' => 'Filtros predeterminados',
    'Your board doesn\'t have any columns!' => '¡Su tablero no tiene columnas!',
    'Change column position' => 'Cambiar la posición de la columna',
    'Switch to the project overview' => 'Cambiar a la vista general del proyecto',
    'User filters' => 'Filtros de usuario(a)',
    'Category filters' => 'Filtros de categorías',
    'Upload a file' => 'Cargar un archivo',
    'View file' => 'Ver archivo',
    'Last activity' => 'Última actividad',
    'Change subtask position' => 'Cambiar la posición de la subtarea',
    'This value must be greater than %d' => 'Este valor no debe de ser más grande que %d',
    'Another swimlane with the same name exists in the project' => 'En el proyecto existe otro carril con el mismo nombre',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Ejemplo: https://example.kanboard.org/ (utilizado para generar URLs absolutas)',
    'Actions duplicated successfully.' => 'Acciones duplicadas correctamente.',
    'Unable to duplicate actions.' => 'No se pueden duplicar acciones.',
    'Add a new action' => 'Añadir una acción nueva',
    'Import from another project' => 'Importar desde otro proyecto',
    'There is no action at the moment.' => 'No hay acción en este momento.',
    'Import actions from another project' => 'Importar acciones de otro proyecto',
    'There is no available project.' => 'No hay proyecto disponible.',
    'Local File' => 'Archivo local',
    'Configuration' => 'Configuración',
    'PHP version:' => 'Versión de PHP:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Versión del sistema operativo:',
    'Database version:' => 'Versión de base de datos:',
    'Browser:' => 'Navegador:',
    'Task view' => 'Vista de la tarea',
    'Edit task' => 'Editar tarea',
    'Edit description' => 'Editar Descripción',
    'New internal link' => 'Nuevo enlace interno',
    'Display list of keyboard shortcuts' => 'Mostrar lista de atajos de teclado',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Subir mi imagen de avatar',
    'Remove my image' => 'Eliminar mi imagen',
    'The OAuth2 state parameter is invalid' => 'El parámetro de estado OAuth2 no es válido',
    'User not found.' => 'Usuario(a) no encontrado(a).',
    'Search in activity stream' => 'Buscar en el flujo de actividades',
    'My activities' => 'Mis actividades',
    'Activity until yesterday' => 'Actividad hasta ayer',
    'Activity until today' => 'Actividad hasta hoy',
    'Search by creator: ' => 'Búsqueda por creador: ',
    'Search by creation date: ' => 'Búsqueda por fecha de creación: ',
    'Search by task status: ' => 'Búsqueda por estado de la tarea: ',
    'Search by task title: ' => 'Buscar por título de tarea: ',
    'Activity stream search' => 'Búsqueda de flujo de actividad',
    'Projects where "%s" is manager' => 'Proyectos donde "%s" es gerente',
    'Projects where "%s" is member' => 'Proyectos donde "%s" es miembro',
    'Open tasks assigned to "%s"' => 'Tareas abiertas asignadas a "%s"',
    'Closed tasks assigned to "%s"' => 'Tareas cerradas asignadas a "%s"',
    'Assign automatically a color based on a priority' => 'Asignar automáticamente un color basado en una prioridad',
    'Overdue tasks for the project(s) "%s"' => 'Tareas vencidas para el (los) proyecto(s) "%s"',
    'Upload files' => 'Subir archivos',
    'Installed Plugins' => 'Plugins instalados',
    'Plugin Directory' => 'Directorio de Plugins',
    'Plugin installed successfully.' => 'Plugin instalado correctamente.',
    'Plugin updated successfully.' => 'Plugin actualizado correctamente.',
    'Plugin removed successfully.' => 'Plugin eliminado correctamente.',
    'Subtask converted to task successfully.' => 'Subtarea convertida a la tarea con éxito.',
    'Unable to convert the subtask.' => 'No se puede convertir la subtarea.',
    'Unable to extract plugin archive.' => 'No se puede extraer archivo plugin.',
    'Plugin not found.' => 'No se ha encontrado el plugin.',
    'You don\'t have the permission to remove this plugin.' => 'No tienes permiso para eliminar este plugin.',
    'Unable to download plugin archive.' => 'No es posible descargar archivos plugin.',
    'Unable to write temporary file for plugin.' => 'No se puede escribir el archivo temporal para el plugin.',
    'Unable to open plugin archive.' => 'No se puede abrir el archivo de plugin',
    'There is no file in the plugin archive.' => 'No hay ningún archivo en el archivo de plugins.',
    'Create tasks in bulk' => 'Crear tareas en lote',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Tu instancia de Kanboard no está configurada para instalar complementos desde la interfaz de usuario(a).',
    'There is no plugin available.' => 'No hay un plugin disponible.',
    'Install' => 'Instalar',
    'Update' => 'Actualizar',
    'Up to date' => 'Hasta la fecha',
    'Not available' => 'No disponible',
    'Remove plugin' => 'Eliminar plugin',
    'Do you really want to remove this plugin: "%s"?' => '¿Realmente desea eliminar este plugin: "%s"?',
    'Uninstall' => 'Desinstalar',
    'Listing' => 'Listado',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Gestionar proyectos',
    'Convert to task' => 'Convertir en tarea',
    'Convert sub-task to task' => 'Convertir subtarea en tarea',
    'Do you really want to convert this sub-task to a task?' => '¿Realmente desea convertir esta subtarea a una tarea?',
    'My task title' => 'Título de mi tarea',
    'Enter one task by line.' => 'Ingrese una tarea por línea.',
    'Number of failed login:' => 'Número de inicio de sesión fallido:',
    'Account locked until:' => 'Cuenta bloqueada hasta:',
    'Email settings' => 'Ajustes de correo electrónico',
    'Email sender address' => 'Dirección del remitente del correo electrónico',
    'Email transport' => 'Transporte por correo electrónico',
    'Webhook token' => 'Token Webhook',
    'Project tags management' => 'Gestión de etiquetas de proyecto',
    'Tag created successfully.' => 'Etiqueta creada correctamente.',
    'Unable to create this tag.' => 'No se puede crear esta etiqueta.',
    'Tag updated successfully.' => 'Etiqueta actualizada correctamente.',
    'Unable to update this tag.' => 'No se puede actualizar esta etiqueta.',
    'Tag removed successfully.' => 'Etiqueta eliminada correctamente.',
    'Unable to remove this tag.' => 'No se ha podido eliminar esta etiqueta.',
    'Global tags management' => 'Gestión de etiquetas globales',
    'Tags' => 'Etiquetas',
    'Tags management' => 'Gestión de etiquetas',
    'Add new tag' => 'Añadir nueva etiqueta',
    'Edit a tag' => 'Modificar una etiqueta',
    'Project tags' => 'Etiquetas del proyecto',
    'There is no specific tag for this project at the moment.' => 'No hay una etiqueta específica para este proyecto en este momento.',
    'Tag' => 'Etiqueta',
    'Remove a tag' => 'Eliminar una etiqueta',
    'Do you really want to remove this tag: "%s"?' => '¿Desea realmente eliminar esta etiqueta: "%s"?',
    'Global tags' => 'Etiquetas globales',
    'There is no global tag at the moment.' => 'No hay una etiqueta global en este momento.',
    'This field cannot be empty' => 'Este campo no puede estar vacío',
    'Close a task when there is no activity in a specific column' => 'Cierra una tarea cuando no hay actividad en una columna específica',
    '%s removed a subtask for the task #%d' => '%s eliminó una subtarea para la tarea %d',
    '%s removed a comment on the task #%d' => '%s eliminó un comentario para la tarea %d',
    'Comment removed on task #%d' => 'Comentario eliminado en la tarea  #%d',
    'Subtask removed on task #%d' => 'Subtarea eliminada en la tarea #%d',
    'Hide tasks in this column in the dashboard' => 'Ocultar tareas en esta columna en el tablero',
    '%s removed a comment on the task %s' => '%s eliminó un comentario para la tarea %s',
    '%s removed a subtask for the task %s' => '%s eliminó una subtarea para la tarea %s',
    'Comment removed' => 'Comentario eliminado',
    'Subtask removed' => 'Sub-tarea eliminada',
    '%s set a new internal link for the task #%d' => '%s estableció un nuevo enlace interno para la tarea %d',
    '%s removed an internal link for the task #%d' => '%s eliminó un nuevo enlace interno para la tarea %d',
    'A new internal link for the task #%d has been defined' => 'Se ha definido un nuevo enlace interno para la tarea #%d',
    'Internal link removed for the task #%d' => 'Enlace interno eliminado para la tarea #%d',
    '%s set a new internal link for the task %s' => '%s estableció un nuevo enlace interno para la tarea %s',
    '%s removed an internal link for the task %s' => '%s eliminó un enlace interno para la tarea %s',
    'Automatically set the due date on task creation' => 'Establecer automáticamente la fecha de vencimiento en la creación de tareas',
    'Move the task to another column when closed' => 'Mover la tarea a otra columna cuando esté cerrada',
    'Move the task to another column when not moved during a given period' => 'Mover la tarea a otra columna cuando no se mueve durante un período determinado',
    'Dashboard for %s' => 'Tablero para %s',
    'Tasks overview for %s' => 'Visión general de tareas para %s',
    'Subtasks overview for %s' => 'Visión general de subtareas para %s',
    'Projects overview for %s' => 'Visión general de proyectos para %s',
    'Activity stream for %s' => 'Flujo de actividad para %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Asignar un color cuando la tarea se mueve a un carril específico',
    'Assign a priority when the task is moved to a specific swimlane' => 'Asignar una prioridad cuando la tarea se mueve a un carril específico',
    'User unlocked successfully.' => 'Usuario(a) desbloqueado(a) correctamente.',
    'Unable to unlock the user.' => 'No se puede desbloquear el usuario(a).',
    'Move a task to another swimlane' => 'Mueve una tarea a otro carril',
    'Creator Name' => 'Nombre del Creador',
    'Time spent and estimated' => 'Tiempo empleado y estimado',
    'Move position' => 'Mover la posición',
    'Move task to another position on the board' => 'Mover la tarea a otra posición en el tablero',
    'Insert before this task' => 'Insertar antes de esta tarea',
    'Insert after this task' => 'Insertar después de esta tarea',
    'Unlock this user' => 'Desbloquear este usuario(a)',
    'Custom Project Roles' => 'Roles de proyecto personalizados',
    'Add a new custom role' => 'Agregar un nuevo rol personalizado',
    'Restrictions for the role "%s"' => 'Restricciones para el rol "%s"',
    'Add a new project restriction' => 'Añadir una nueva restricción de proyecto',
    'Add a new drag and drop restriction' => 'Añadir una nueva restricción de arrastrar y soltar',
    'Add a new column restriction' => 'Agregar una nueva restricción de columna',
    'Edit this role' => 'Editar este rol',
    'Remove this role' => 'Eliminar este rol',
    'There is no restriction for this role.' => 'No hay restricción para este rol.',
    'Only moving task between those columns is permitted' => 'Sólo se permite el movimiento de una tarea entre esas columnas',
    'Close a task in a specific column when not moved during a given period' => 'Cierra una tarea en una columna específica cuando no se mueve durante un período determinado',
    'Edit columns' => 'Editar columnas',
    'The column restriction has been created successfully.' => 'La restricción de columna se ha creado correctamente.',
    'Unable to create this column restriction.' => 'No se puede crear esta restricción de columna.',
    'Column restriction removed successfully.' => 'Se ha eliminado correctamente la restricción de columna.',
    'Unable to remove this restriction.' => 'No se puede eliminar esta restricción.',
    'Your custom project role has been created successfully.' => 'El rol de proyecto personalizado se ha creado correctamente.',
    'Unable to create custom project role.' => 'No se puede crear un rol de proyecto personalizado.',
    'Your custom project role has been updated successfully.' => 'Su rol de proyecto personalizado se ha actualizado correctamente.',
    'Unable to update custom project role.' => 'No se puede actualizar el rol de proyecto personalizado.',
    'Custom project role removed successfully.' => 'El rol de proyecto personalizado se eliminó correctamente.',
    'Unable to remove this project role.' => 'No se pudo eliminar esta función del proyecto.',
    'The project restriction has been created successfully.' => 'La restricción del proyecto se ha creado con éxito.',
    'Unable to create this project restriction.' => 'No se puede crear esta restricción de proyecto.',
    'Project restriction removed successfully.' => 'Se ha eliminado correctamente la restricción de proyecto.',
    'You cannot create tasks in this column.' => 'No puede crear tareas en esta columna.',
    'Task creation is permitted for this column' => 'La creación de tareas está permitida para esta columna',
    'Closing or opening a task is permitted for this column' => 'El cierre o apertura de una tarea está permitido para esta columna',
    'Task creation is blocked for this column' => 'La creación de tareas está bloqueada para esta columna',
    'Closing or opening a task is blocked for this column' => 'El cierre o apertura de una tarea está bloqueado para esta columna',
    'Task creation is not permitted' => 'No se permite la creación de tareas',
    'Closing or opening a task is not permitted' => 'No se permite cerrar ni abrir una tarea',
    'New drag and drop restriction for the role "%s"' => 'Nueva restricción de arrastrar y soltar para el rol "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Las personas pertenecientes a este rol sólo podrán mover las tareas entre la columna de origen y la de destino.',
    'Remove a column restriction' => 'Eliminar una restricción de columna',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => '¿Realmente desea eliminar esta restricción de columna: "%s" a "%s"?',
    'New column restriction for the role "%s"' => 'Nueva restricción de columna para el rol "%s"',
    'Rule' => 'Regla',
    'Do you really want to remove this column restriction?' => '¿Realmente desea eliminar esta restricción de columna?',
    'Custom roles' => 'Roles personalizados',
    'New custom project role' => 'Nuevo rol de proyecto personalizado',
    'Edit custom project role' => 'Editar un rol de proyecto personalizado',
    'Remove a custom role' => 'Eliminar un rol personalizado',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => '¿Realmente desea eliminar este rol personalizado: "%s"? Todas las personas asignadas a este rol se convertirán en miembros del proyecto.',
    'There is no custom role for this project.' => 'No hay ningun rol personalizado para este proyecto.',
    'New project restriction for the role "%s"' => 'Nueva restricción de proyecto para el rol "%s"',
    'Restriction' => 'Restricción',
    'Remove a project restriction' => 'Eliminar una restricción de proyecto',
    'Do you really want to remove this project restriction: "%s"?' => '¿Realmente desea eliminar esta restricción de proyecto: "%s"?',
    'Duplicate to multiple projects' => 'Duplicar en varios proyectos',
    'This field is required' => 'Este campo es requerido',
    'Moving a task is not permitted' => 'No se permite mover una tarea',
    'This value must be in the range %d to %d' => 'Este valor debe estar en el rango %d a %d',
    'You are not allowed to move this task.' => 'No se le permite mover esta tarea.',
    'API User Access' => 'Acceso de usuario de API',
    'Preview' => 'Previsualizar',
    'Write' => 'Escribir',
    'Write your text in Markdown' => 'Redacta el texto en Markdown',
    'No personal API access token registered.' => 'No se ha registrado ningún token de acceso a API personal.',
    'Your personal API access token is "%s"' => 'Su token de acceso a la API personal es "%s"',
    'Remove your token' => 'Elimine su token',
    'Generate a new token' => 'Generar un nuevo token',
    'Showing %d-%d of %d' => 'Mostrando %d-%d de %d',
    'Outgoing Emails' => 'Correo electrónico saliente',
    'Add or change currency rate' => 'Añadir o cambiar el tipo de cambio',
    'Reference currency: %s' => 'Divisa de referencia: %s',
    'Add custom filters' => 'Añadir filtros personalizados',
    'Export' => 'Exportar',
    'Add link label' => 'Añadir etiqueta de enlace',
    'Incompatible Plugins' => 'Plugins incompatibles',
    'Compatibility' => 'Compatibilidad',
    'Permissions and ownership' => 'Permisos y propiedad',
    'Priorities' => 'Prioridades',
    'Close this window' => 'Cierra esta ventana',
    'Unable to upload this file.' => 'No se puede subir este archivo.',
    'Import tasks' => 'Importar tareas',
    'Choose a project' => 'Elija un proyecto',
    'Profile' => 'Perfil',
    'Application role' => 'Rol de la aplicación',
    '%d invitations were sent.' => '%d invitaciones enviadas.',
    '%d invitation was sent.' => '%d invitación fue enviada.',
    'Unable to create this user.' => 'No se puede crear este(a) usuario(a).',
    'Kanboard Invitation' => 'Invitación de Kanboard',
    'Visible on dashboard' => 'Visible en el tablero',
    'Created at:' => 'Creado en:',
    'Updated at:' => 'Actualizado en:',
    'There is no custom filter.' => 'No hay un filtro personalizado.',
    'New User' => 'Nuevo(a) usuario(a)',
    'Authentication' => 'Autenticación',
    'If checked, this user will use a third-party system for authentication.' => 'Si está marcado, este(a) usuario(a) utilizará un sistema de terceros para la autenticación.',
    'The password is necessary only for local users.' => 'La contraseña sólo es necesaria para lo(a)s usuario(a)s locales.',
    'You have been invited to register on Kanboard.' => 'Te han invitado a registrarte en Kanboard.',
    'Click here to join your team' => 'Haz clic aquí para unirte a tu equipo',
    'Invite people' => 'Invitar personas',
    'Emails' => ' correos electrónicos',
    'Enter one email address by line.' => 'Ingrese una dirección de correo electrónico por línea.',
    'Add these people to this project' => 'Añadir a estas personas a este proyecto',
    'Add this person to this project' => 'Añadir a esta persona a este proyecto',
    'Sign-up' => 'Regístrate',
    'Credentials' => 'Credenciales',
    'New user' => 'Añadir un(a) usuario(a)',
    'This username is already taken' => 'Este nombre de usuario(a) ya está en uso',
    'Your profile must have a valid email address.' => 'Su perfil debe tener una dirección de correo electrónico válido.',
    'TRL - Turkish Lira' => 'TRL - Lira Turca',
    'The project email is optional and could be used by several plugins.' => 'El correo electrónico del proyecto es opcional y podría ser usado por varios plugins',
    'The project email must be unique across all projects' => 'El correo electrónico del proyecto debe ser único entre todos los proyectos',
    'The email configuration has been disabled by the administrator.' => 'La configuración de  correo electrónico se ha deshabilitado por el administrador',
    'Close this project' => 'Cerrar este proyecto',
    'Open this project' => 'Abrir este proyecto',
    'Close a project' => 'Cerrar un proyecto',
    'Do you really want to close this project: "%s"?' => '¿Realmente quiere cerrar este proyecto: "%s"?',
    'Reopen a project' => 'Reabrir un proyecto',
    'Do you really want to reopen this project: "%s"?' => '¿Realmente quiere reabrir este proyecto: "%s"?',
    'This project is open' => 'Este proyecto está abierdo',
    'This project is closed' => 'Este proyecto está cerrado',
    'Unable to upload files, check the permissions of your data folder.' => 'No se pueden cargar archivos, verifique los permisos de su carpeta de datos (data)',
    'Another category with the same name exists in this project' => 'Ya existe otra categoría con el mismo nombre en este proyecto',
    'Comment sent by email successfully.' => 'Comentario enviado exitosamente por correo electrónico',
    'Sent by email to "%s" (%s)' => 'Enviado por correo electrónico a "%s" (%s)',
    'Unable to read uploaded file.' => 'No se pudo leer el archivo cargado',
    'Database uploaded successfully.' => 'Base de datos cargada exitosamente',
    'Task sent by email successfully.' => 'Tarea enviada exitosamente por correo electrónico',
    'There is no category in this project.' => 'No hay categorías en este proyecto',
    'Send by email' => 'Enviar por  correo electrónico',
    'Create and send a comment by email' => 'Crear y enviar un comentario por correo electrónico',
    'Subject' => 'Asunto',
    'Upload the database' => 'Cargar la base de datos',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Podría cargar la base de datos Sqlite descargada previamente (formato Gzip)',
    'Database file' => 'Archivo de Base de Datos',
    'Upload' => 'Cargar',
    'Your project must have at least one active swimlane.' => 'Su proyecto debe tener al menos un carril activo',
    'Project: %s' => 'Proyecto: %s',
    'Automatic action not found: "%s"' => 'No se encontró la acción automática: "%s"',
    '%d projects' => '%d proyectos',
    '%d project' => '%d proyecto',
    'There is no project.' => 'No hay proyecto',
    'Sort' => 'Ordenar',
    'Project ID' => 'ID Proyecto',
    'Project name' => 'Nombre del Proyecto',
    'Public' => 'Público',
    'Personal' => 'Privado',
    '%d tasks' => '%d tareas',
    '%d task' => '%d tarea',
    'Task ID' => 'ID Tarea',
    'Assign automatically a color when due date is expired' => 'Asignar un color automáticamente cuando la fecha de vencimiento haya expirado',
    'Total score in this column across all swimlanes' => 'Puntaje Total en esta columna para todos los carriles',
    'HRK - Kuna' => 'HRK - Kuna',
    'ARS - Argentine Peso' => 'ARS - Peso Argentino',
    'COP - Colombian Peso' => 'COP - Peso Colombiano',
    '%d groups' => '%d grupos',
    '%d group' => '%d grupo',
    'Group ID' => 'ID Grupo',
    'External ID' => 'ID Externa',
    '%d users' => '%d usuario(a)s',
    '%d user' => '%d usuario(a)',
    'Hide subtasks' => 'Ocultar subtareas',
    'Show subtasks' => 'Mostrar subtareas',
    'Authentication Parameters' => 'Parámetros de Autenticación',
    'API Access' => 'Acceso API',
    'No users found.' => 'No se encontraron usuario(a)s',
    'User ID' => 'ID del Usuario(a)',
    'Notifications are activated' => 'Las notificaciones están activadas',
    'Notifications are disabled' => 'Las notificaciones están deshabilitadas',
    'User disabled' => 'Usuario(a) deshabilitado(a)',
    '%d notifications' => '%d notificaciones',
    '%d notification' => '%d notificación',
    'There is no external integration installed.' => 'No se ha instalado ninguna integración externa.',
    'You are not allowed to update tasks assigned to someone else.' => 'No se le permite actualizar tareas asignadas a alguien más.',
    'You are not allowed to change the assignee.' => 'No se le permite cambiar la persona asignada.',
    'Task suppression is not permitted' => 'No está permitido la eliminación de tarea',
    'Changing assignee is not permitted' => 'No está permitido cambiar la persona asignada',
    'Update only assigned tasks is permitted' => 'Está permitido actualizar solo las tareas asignadas',
    'Only for tasks assigned to the current user' => 'Solo para las tareas asignadas al usuario(a) actual',
    'My projects' => 'Mis proyectos',
    'You are not a member of any project.' => 'No eres miembro de ningún proyecto.',
    'My subtasks' => 'Mis subtareas',
    '%d subtasks' => '%d subtareas',
    '%d subtask' => '%d subtarea',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Mover tareas entre esas columnas solo está permitido para las tareas asignadas al usuario(a) actual.',
    '[DUPLICATE]' => '[DUPLICAR]',
    'DKK - Danish Krona' => 'DKK - Corona Danesa',
    'Remove user from group' => 'Eliminar usuario(a) del grupo',
    'Assign the task to its creator' => 'Asignar la tarea a su creador',
    'This task was sent by email to "%s" with subject "%s".' => 'Esta tarea fue enviada por correo a "%s" con el asunto "%s".',
    'Predefined Email Subjects' => 'Asuntos de correo predefinidos',
    'Write one subject by line.' => 'Escriba un asunto por línea.',
    'Create another link' => 'Crear otro enlace',
    'BRL - Brazilian Real' => 'BRL - Real brasileño',
    'Add a new Kanboard task' => 'Agregar una nueva tarea de Kanboard',
    'Subtask not started' => 'Subtarea no iniciada',
    'Subtask currently in progress' => 'Subtarea actualmente en progreso',
    'Subtask completed' => 'Subtarea completada',
    'Subtask added successfully.' => 'Subtarea agregada con éxito.',
    '%d subtasks added successfully.' => '%d subtareas agregadas con éxito.',
    'Enter one subtask by line.' => 'Ingrese una subtarea por línea.',
    'Predefined Contents' => 'Contenidos predefinidos',
    'Predefined contents' => 'Contenidos predefinidos',
    'Predefined Task Description' => 'Descripción de tarea predefinida',
    'Do you really want to remove this template? "%s"' => '¿Realmente quieres eliminar esta plantilla? "%s"',
    'Add predefined task description' => 'Agregar descripción de tarea predefinida',
    'Predefined Task Descriptions' => 'Descripciones de tareas predefinidas',
    'Template created successfully.' => 'Plantilla creada con éxito',
    'Unable to create this template.' => 'No se puede crear esta plantilla.',
    'Template updated successfully.' => 'No se puede actualizar esta plantilla.',
    'Unable to update this template.' => 'No se puede actualizar esta plantilla.',
    'Template removed successfully.' => 'Plantilla eliminada con éxito.',
    'Unable to remove this template.' => 'No se puede eliminar esta plantilla.',
    'Template for the task description' => 'Plantilla para la descripción de la tarea',
    'The start date is greater than the end date' => 'La fecha de inicio es mayor que la fecha de finalización',
    'Tags must be separated by a comma' => 'Las etiquetas deben estar separadas por una coma',
    'Only the task title is required' => 'Solo se requiere el título de la tarea',
    'Creator Username' => 'Nombre del creador',
    'Color Name' => 'Nombre de color',
    'Column Name' => 'Nombre de columna',
    'Swimlane Name' => 'Nombre del carril',
    'Time Estimated' => 'Tiempo estimado',
    'Time Spent' => 'Tiempo empleado',
    'External Link' => 'Enlace externo',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Esta característica habilita el feed iCal, el feed RSS y la vista de la pizarra pública.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Detener el temporizador de todas las subtareas al mover una tarea a otra columna',
    'Subtask Title' => 'Título de subtarea',
    'Add a subtask and activate the timer when moving a task to another column' => 'Agregar una subtarea y activar el temporizador al mover una tarea a otra columna',
    'days' => 'dias',
    'minutes' => 'minutos',
    'seconds' => 'segundos',
    'Assign automatically a color when preset start date is reached' => 'Asigna automáticamente un color cuando se alcanza la fecha de inicio preestablecida',
    'Move the task to another column once a predefined start date is reached' => 'Mover la tarea a otra columna una vez que se alcanza una fecha de inicio predefinida',
    'This task is now linked to the task %s with the relation "%s"' => 'Esta tarea ahora está vinculada a la tarea %s con la relación "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'El enlace con la relación "%s" con la tarea %s se ha eliminado',
    'Custom Filter:' => 'Filtro personalizado:',
    'Unable to find this group.' => 'No se puede encontrar este grupo.',
    '%s moved the task #%d to the column "%s"' => '%s movió la tarea #%d a la columna "%s',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s movió la tarea #%d a la posición %d en la columna "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s movió la tarea #%d al carril "%s"',
    '%sh spent' => '%sh empleados',
    '%sh estimated' => '%sh estimado',
    'Select All' => 'Seleccionar todo',
    'Unselect All' => 'Deseleccionar todo',
    'Apply action' => 'Aplicar acción',
    'Move selected tasks to another column or swimlane' => 'Mover tareas seleccionadas a otra columna',
    'Edit tasks in bulk' => 'Editar tareas en masa',
    'Choose the properties that you would like to change for the selected tasks.' => 'Elija las propiedades que le gustaría cambiar para las tareas seleccionadas.',
    'Configure this project' => 'Configurar este proyecto',
    'Start now' => 'Empezar ahora',
    '%s removed a file from the task #%d' => '%s eliminó un archivo de la tarea #%d',
    'Attachment removed from task #%d: %s' => 'Adjunto eliminado de la tarea #%d: %s',
    'No color' => 'Sin color',
    'Attachment removed "%s"' => 'Adjunto eliminado "%s"',
    '%s removed a file from the task %s' => '%s eliminó un archivo de la tarea %s',
    'Move the task to another swimlane when assigned to a user' => 'Mover la tarea a otro carril cuando se le asigna a un usuario(a)',
    'Destination swimlane' => 'Carril de destino',
    'Assign a category when the task is moved to a specific swimlane' => 'Asigne una categoría cuando la tarea se mueva a un carril específico',
    'Move the task to another swimlane when the category is changed' => 'Mueve la tarea a otro carril cuando se cambia la categoría',
    'Reorder this column by priority (ASC)' => 'Reordenar esta columna por prioridad (ASC)',
    'Reorder this column by priority (DESC)' => 'Reordenar esta columna por prioridad (DESC)',
    'Reorder this column by assignee and priority (ASC)' => 'Reordenar esta columna por asignación y prioridad (ASC)',
    'Reorder this column by assignee and priority (DESC)' => 'Reordenar esta columna por asignación y prioridad (DESC)',
    'Reorder this column by assignee (A-Z)' => 'Reordenar esta columna por persona asignada (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Reordenar esta columna por persona asignada (Z-A)',
    'Reorder this column by due date (ASC)' => 'Reordenar esta columna por fecha de vencimiento (ASC)',
    'Reorder this column by due date (DESC)' => 'Reordenar esta columna por fecha de vencimiento (DESC)',
    'Reorder this column by id (ASC)' => 'Reordenar esta columna por id (ASC)',
    'Reorder this column by id (DESC)' => 'Reordenar esta columna por id (DESC)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s movió la tarea #%d "%s" al proyecto "%s',
    'Task #%d "%s" has been moved to the project "%s"' => 'La tarea #%d "%s" se movió al proyecto "%s',
    'Move the task to another column when the due date is less than a certain number of days' => 'Mueva la tarea a otra columna cuando la fecha de vencimiento sea inferior a un cierto número de días',
    'Automatically update the start date when the task is moved away from a specific column' => 'Actualizar automáticamente la fecha de inicio cuando la tarea se mueve fuera de una columna específica',
    'HTTP Client:' => 'Cliente HTTP:',
    'Assigned' => 'Asignado',
    'Task limits apply to each swimlane individually' => 'Los límites de tareas se aplican a cada carril de forma individual',
    'Column task limits apply to each swimlane individually' => 'Los límites de tareas por columna se aplican a cada carril de forma individual',
    'Column task limits are applied to each swimlane individually' => 'Los límites de tareas por columna se aplican a cada carril de forma individual',
    'Column task limits are applied across swimlanes' => 'Los límites de tareas por columna se aplican a través de los carriles',
    'Task limit: ' => 'Límite de tareas:',
    'Change to global tag' => 'Cambiar a etiqueta global',
    'Do you really want to make the tag "%s" global?' => '¿Realmente quieres hacer global la etiqueta "%s"?',
    'Enable global tags for this project' => 'Habilitar etiquetas globales para este proyecto',
    'Group membership(s):' => 'Membresía(s) de grupo:',
    '%s is a member of the following group(s): %s' => '%s es miembro del(los) siguiente(s) grupo(s): %s',
    '%d/%d group(s) shown' => '%d/%d grupo(s) mostrado(s)',
    'Subtask creation or modification' => 'Creación o modificación de subtareas',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Asignar la tarea a un usuario específico cuando la tarea se mueve a un carril específico',
    'Comment' => 'Comentario',
    'Collapse vertically' => 'Contraer verticalmente',
    'Expand vertically' => 'Expandir verticalmente',
    'MXN - Mexican Peso' => 'MXN - Peso Mexicano',
    'Estimated vs actual time per column' => 'Tiempo estimado vs tiempo real por columna',
    'HUF - Hungarian Forint' => 'HUF - Florín Húngaro',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => '¡Debes seleccionar un archivo para subir como tu avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '¡El archivo que subiste no es una imagen válida! (Solo se permiten *.gif, *.jpg, *.jpeg y *.png)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Establecer automáticamente la fecha de vencimiento cuando la tarea se mueve fuera de una columna específica',
    'No other projects found.' => 'No se encontraron otros proyectos.',
    'Tasks copied successfully.' => 'Tareas copiadas con éxito.',
    'Unable to copy tasks.' => 'No se pudieron copiar las tareas.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Tema claro',
    'Dark theme' => 'Tema oscuro',
    'Automatic theme - Sync with system' => 'Tema automático - Sincronizar con el sistema',
    'Application managers or more' => 'Gerentes de aplicación o más',
    'Administrators' => 'Administradores',
    'Visibility:' => 'Visibilidad:',
    'Standard users' => 'Usuarios estándar',
    'Visibility is required' => 'La visibilidad es obligatoria',
    'The visibility should be an app role' => 'La visibilidad debe ser un rol de aplicación',
    'Reply' => 'Responder',
    '%s wrote: ' => '%s escribió:',
    'Number of visible tasks in this column and swimlane' => 'Número de tareas visibles en esta columna y carril',
    'Number of tasks in this swimlane' => 'Número de tareas en este carril',
    'Unable to find another subtask in progress, you can close this window.' => 'No se puede encontrar otra subtarea en progreso, puede cerrar esta ventana.',
    'This theme is invalid' => 'Este tema no es válido',
    'This role is invalid' => 'Este rol no es válido',
    'This timezone is invalid' => 'Esta zona horaria no es válida',
    'This language is invalid' => 'Este idioma no es válido',
    'This URL is invalid' => 'Esta URL no es válida',
    'Date format invalid' => 'Formato de fecha inválido',
    'Time format invalid' => 'Formato de hora inválido',
    'Invalid Mail transport' => 'Transporte de correo inválido',
    'Color invalid' => 'Color inválido',
    'This value must be greater or equal to %d' => 'Este valor debe ser mayor o igual a %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Agregar un BOM al principio del archivo (requerido para Microsoft Excel)',
    'Just add these tag(s)' => 'Simplemente agregue esta(s) etiqueta(s)',
    'Remove internal link(s)' => 'Eliminar enlace(s) interno(s)',
    'Import tasks from another project' => 'Importar tareas de otro proyecto',
    'Select the project to copy tasks from' => 'Seleccione el proyecto desde el que copiar tareas',
    'The total maximum allowed attachments size is %sB.' => 'El tamaño total máximo permitido para los archivos adjuntos es %sB.',
    'Add attachments' => 'Agregar archivos adjuntos',
    'Task #%d "%s" is overdue' => 'La tarea #%d "%s" está vencida',
    'Enable notifications by default for all new users' => 'Habilitar notificaciones por defecto para todos los nuevos usuarios',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Asignar la tarea a su creador para columnas específicas si no se ha establecido un responsable manualmente',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Asignar una tarea al usuario conectado al cambiar de columna a la columna especificada si no hay ningún usuario asignado',
];
